Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
/home/mattis/projects/websites/dighl/edictor/src/edictor/__init__.py | 1 | 0 | 0 | 100%
/home/mattis/projects/websites/dighl/edictor/src/edictor/cli.py | 113 | 20 | 8 | 82%
/home/mattis/projects/websites/dighl/edictor/src/edictor/server.py | 51 | 11 | 0 | 78%
/home/mattis/projects/websites/dighl/edictor/src/edictor/util.py | 333 | 27 | 64 | 92%
/home/mattis/projects/websites/dighl/edictor/src/edictor/wordlist.py | 46 | 17 | 0 | 63%
test_cli.py | 23 | 0 | 0 | 100%
test_server.py | 32 | 1 | 0 | 97%
test_util.py | 156 | 7 | 0 | 96%
test_wordlist.py | 18 | 0 | 0 | 100%
Total | 773 | 83 | 72 | 89%

No items found using the specified filter.